////////////////////////////////////////////////////////////////
// タイマーガジェット
//   Copyright (C) 2008 - 2012 AAOh inc.
////////////////////////////////////////////////////////////////

/**
 * @fileOverview タイマーガジェット
 * @author       $Author: fujishiro $
 */

(function () {
/**
 * Main。
 *
 * @constructor
 */
timer.Main = aaoh.kaze.Gadget.extend(
	aaoh.sora.MainEx, function() {
	this.measureTime = 0;    // 計測時間(msec)
	this.stopTime    = 0;    // 終了時間(msec)
	this.suspendDate = null; // 一時停止時間(Date)

	this.flgSts        = aaoh.sora.App.control.FLG_STOP; // 状態フラグ
	this.lblFgColor    = null;
	this.lblAlertColor = '#ff0000';
	this.btnBgImgs     = new Array();

	this.alarmRepeatFile  = null;
	this.alarmRepeatTimer = new aaoh.kaze.Timer(this);

	this.ALARM_SET_INTERVAL = 200; // msec
	this.alarmSetHourTimer = new aaoh.kaze.Timer(this);
	this.alarmSetMinTimer  = new aaoh.kaze.Timer(this);
	this.alarmSetSecTimer  = new aaoh.kaze.Timer(this);
	this.isAlarmSetHourAdd = true;
	this.isAlarmSetMinAdd  = true;
	this.isAlarmSetSecAdd  = true;

	this.topObj     = this.getTopObject();
	this.lblHour    = aaoh.kaze.Gadget.$('lblHour');
	this.lblHourSep = aaoh.kaze.Gadget.$('lblHourSep');
	this.lblMin     = aaoh.kaze.Gadget.$('lblMin');
	this.lblMinSep  = aaoh.kaze.Gadget.$('lblMinSep');
	this.lblSec     = aaoh.kaze.Gadget.$('lblSec');
	this.lblSecSep  = aaoh.kaze.Gadget.$('lblSecSep');
	this.lblMsec    = aaoh.kaze.Gadget.$('lblMsec');
	this.btnStart   = aaoh.kaze.Gadget.$('btnStart');
	this.btnStop    = aaoh.kaze.Gadget.$('btnStop');
	this.lblPreset  = aaoh.kaze.Gadget.$('lblPreset');

	this.alertTimer1 = new aaoh.kaze.Timer(this);
	this.alertTimer2 = new aaoh.kaze.Timer(this);
	this.dispTimer   = new aaoh.kaze.Timer(this);
});
	/**
	 * 計測時間設定。
	 */
	timer.Main.prototype.
	setMeasureTime = function() {
		var hour    = aaoh.kaze.Element.getValue(this.lblHour);
		var min     = aaoh.kaze.Element.getValue(this.lblMin);
		var sec     = aaoh.kaze.Element.getValue(this.lblSec);

		var time = aaoh.sora.App.control.getTime(hour, min, sec);
		if (time > 0) {
			this.measureTime = time;
		}
	}

	/**
	 * タイマー時間設定。
	 *
	 * @param {Number} setNo 設定番号
	 */
	timer.Main.prototype.
	setStartTime = function(setNo) {
		// 計測状態の設定
		this.flgSts      = aaoh.sora.App.control.FLG_STOP;
		this.stopTime    = 0;
		this.suspendDate = null;
		this.setStartImg();
		this.setStopImg();

		// 開始時間の設定
		switch (setNo) {
			case 1:
				this.measureTime = aaoh.sora.App.model.data.numTime1;
				break;
			case 2:
				this.measureTime = aaoh.sora.App.model.data.numTime2;
				break;
			case 3:
				this.measureTime = aaoh.sora.App.model.data.numTime3;
				break;

			case 0:
			default:
				break;
		}

		// アラート表示の初期化
		this.alertTimer1.clearTimeout();
		this.alertTimer2.clearInterval();
		this.soundStop();

		// 画面表示
		this.showTimer(this.measureTime);
	}

	/**
	 * 開始ボタンのイメージ変更。
	 */
	timer.Main.prototype.
	setStartImg = function() {
		var tipStart = null;

		// 開始
		if (
			this.flgSts == aaoh.sora.App.control.FLG_STOP
			|| this.flgSts == aaoh.sora.App.control.FLG_SUSPEND
		) {
			aaoh.kaze.Element.setBackgroundImage(
				this.btnStart,
				this.btnBgImgs[aaoh.sora.App.control.FLG_START][0],
				this.btnBgImgs[aaoh.sora.App.control.FLG_START][1],
				this.btnBgImgs[aaoh.sora.App.control.FLG_START][2]
			);
			tipStart = aaoh.sora.App.control.locale.getString('TIP_TIME_START');

		// 一時停止
		} else if (this.flgSts == aaoh.sora.App.control.FLG_START) {
			aaoh.kaze.Element.setBackgroundImage(
				this.btnStart,
				this.btnBgImgs[aaoh.sora.App.control.FLG_SUSPEND][0],
				this.btnBgImgs[aaoh.sora.App.control.FLG_SUSPEND][1],
				this.btnBgImgs[aaoh.sora.App.control.FLG_SUSPEND][2]
			);
			tipStart = aaoh.sora.App.control.locale.getString('TIP_TIME_SUSPEND');
		}

		aaoh.kaze.Element.setForeground(this.lblHour,    this.lblFgColor);
		aaoh.kaze.Element.setForeground(this.lblHourSep, this.lblFgColor);
		aaoh.kaze.Element.setForeground(this.lblMin,     this.lblFgColor);
		aaoh.kaze.Element.setForeground(this.lblMinSep,  this.lblFgColor);
		aaoh.kaze.Element.setForeground(this.lblSec,     this.lblFgColor);
		aaoh.kaze.Element.setForeground(this.lblSecSep,  this.lblFgColor);
		aaoh.kaze.Element.setForeground(this.lblMsec,    this.lblFgColor);
		aaoh.kaze.Element.setForeground(this.lblPreset,  this.lblFgColor);
		aaoh.kaze.Element.setTooltip(this.btnStart, tipStart);
	}

	/**
	 * 開始ボタンのイメージ変更。
	 */
	timer.Main.prototype.
	setStartPushImg = function() {
		// 開始
		if(
			this.flgSts == aaoh.sora.App.control.FLG_STOP
			|| this.flgSts == aaoh.sora.App.control.FLG_SUSPEND
		) {
			aaoh.kaze.Element.setBackgroundImage(
				this.btnStart,
				this.btnBgImgs[aaoh.sora.App.control.FLG_START][2]
			);

		// 一時停止
		} else if (this.flgSts == aaoh.sora.App.control.FLG_START) {
			aaoh.kaze.Element.setBackgroundImage(
				this.btnStart,
				this.btnBgImgs[aaoh.sora.App.control.FLG_SUSPEND][2]
			);
		}
	}

	/**
	 * 停止ボタンのイメージ変更。
	 */
	timer.Main.prototype.
	setStopImg = function() {
		aaoh.kaze.Element.setBackgroundImage(
			this.btnStop,
			this.btnBgImgs[aaoh.sora.App.control.FLG_STOP][0],
			this.btnBgImgs[aaoh.sora.App.control.FLG_STOP][1],
			this.btnBgImgs[aaoh.sora.App.control.FLG_STOP][2]
		);
	}

	/**
	 * 停止ボタンのイメージ変更。
	 */
	timer.Main.prototype.
	setStopPushImg = function() {
		aaoh.kaze.Element.setBackgroundImage(
			this.btnStop,
			this.btnBgImgs[aaoh.sora.App.control.FLG_STOP][2]
		);
	}

	/**
	 * キー入力。
	 *
	 * @param {Object} event イベント
	 */
	timer.Main.prototype.
	setImgInput = function(event) {
		if (event == null) {
			event = aaoh.kaze.Gadget.getEvent();
		}
		var key = event.keyCode;

		// Altが押されている
		if (event.altKey) {
			return;
		}

		// コントロールが押されている
		if (event.ctrlKey) {
			return;
		}

		// シフトが押されている
		if (event.shiftKey) {
			return;
		}

		switch (key) {
			// エンター
			case 13:
				this.setStartPushImg();
				break;

			// エスケープ
			case 27:
				this.setStopPushImg();
				break;

			default:
				break;
		}
	}

	/**
	 * タイマー開始、一時停止。
	 */
	timer.Main.prototype.
	doStart = function() {
		// 開始
		if (
			this.flgSts == aaoh.sora.App.control.FLG_STOP
			|| this.flgSts == aaoh.sora.App.control.FLG_SUSPEND
		) {
			this.flgSts = aaoh.sora.App.control.FLG_START;
			this.setStartImg();

			// 計測時刻の設定
			var nowTime = new Date().getTime();
			if (this.suspendDate == null) {
				this.setMeasureTime();
				this.stopTime = nowTime + this.measureTime;

			} else {
				var suspendTime = nowTime - this.suspendDate.getTime();
				this.stopTime = this.stopTime + suspendTime;

				// 一時停止時間のクリア
				this.suspendDate = null;
			}

			// アラート表示の初期化
			this.alertTimer1.clearTimeout();
			this.alertTimer2.clearInterval();
			this.soundStop();

			// タイマー開始
			this.timer();

		// 一時停止
		} else if (this.flgSts == aaoh.sora.App.control.FLG_START) {
			this.flgSts = aaoh.sora.App.control.FLG_SUSPEND;
			this.setStartImg();

			// 一時停止時間の設定
			this.suspendDate = new Date();
		}
	}

	/**
	 * タイマー停止。
	 */
	timer.Main.prototype.
	doStop = function() {
		this.setStartTime(0);
	}

	/**
	 * キー入力。
	 *
	 * @param {Object} event イベント
	 */
	timer.Main.prototype.
	doInput = function(event) {
		if (event == null) {
			event = aaoh.kaze.Gadget.getEvent();
		}
		var key = event.keyCode;

		// Altが押されている
		if (event.altKey) {
			return;
		}

		// コントロールが押されている
		if (event.ctrlKey) {
			return;
		}

		// シフトが押されている
		if (event.shiftKey) {
			return;
		}

		switch (key) {
			// エンター
			case 13:
				this.doStart();
				break;

			// エスケープ
			case 27:
				this.doStop();
				break;

			default:
				break;
		}
	}

	/**
	 * フォーカス設定。
	 */
	timer.Main.prototype.
	setFocus = function() {
		// ボタンが連打できないようにする
		var element = this.topObj;
		if (aaoh.kaze.Type.isGoogle()) {
			element = aaoh.kaze.Gadget.$('main');
		}
		aaoh.kaze.Element.setFocus(element);
	}

	/**
	 * 計測時間の表示。
	 *
	 * @param {Number} remainTime 残時間
	 */
	timer.Main.prototype.
	showTimer = function(remainTime) {
		var timeList = aaoh.sora.App.control.getShowTime(remainTime);

		// 時間の表示
		aaoh.kaze.Element.setValue(this.lblHour, timeList[0]);
		aaoh.kaze.Element.setValue(this.lblMin,  timeList[1]);
		aaoh.kaze.Element.setValue(this.lblSec,  timeList[2]);
		aaoh.kaze.Element.setValue(this.lblMsec, timeList[3]);
	}

	/**
	 * アラート表示。
	 */
	timer.Main.prototype.
	showAlert = function() {
		this.flgSts   = aaoh.sora.App.control.FLG_STOP;
		this.stopTime = 0;

		// アラート表示
		aaoh.kaze.Element.setBackgroundImage(
			this.btnStart,
			this.btnBgImgs[aaoh.sora.App.control.FLG_START][0],
			this.btnBgImgs[aaoh.sora.App.control.FLG_START][1],
			this.btnBgImgs[aaoh.sora.App.control.FLG_START][2]
		);
		var tipStart = aaoh.sora.App.control.locale.getString('TIP_TIME_START');
		aaoh.kaze.Element.setTooltip(this.btnStart, tipStart);
		var remainTime = 0;
		switch (aaoh.sora.App.model.data.mode) {
			case aaoh.sora.App.control.MODE_COUNTDOWN:
			default:
				remainTime = 0;
				break;

			case aaoh.sora.App.control.MODE_COUNTUP:
				remainTime = this.measureTime;
				break;
		}
		this.showTimer(remainTime);

		this.showTimerAlert();
		this.soundPlay();
		this.showAlertMsg();
	}

	/**
	 * アラート表示。
	 */
	timer.Main.prototype.
	showTimerAlert = function() {
		aaoh.kaze.Element.setForeground(this.lblHour,    this.lblAlertColor);
		aaoh.kaze.Element.setForeground(this.lblHourSep, this.lblAlertColor);
		aaoh.kaze.Element.setForeground(this.lblMin,     this.lblAlertColor);
		aaoh.kaze.Element.setForeground(this.lblMinSep,  this.lblAlertColor);
		aaoh.kaze.Element.setForeground(this.lblSec,     this.lblAlertColor);
		aaoh.kaze.Element.setForeground(this.lblSecSep,  this.lblAlertColor);
		aaoh.kaze.Element.setForeground(this.lblMsec,    this.lblAlertColor);
		aaoh.kaze.Element.setForeground(this.lblPreset,  this.lblAlertColor);
		this.alertTimer1.setTimeout(function() {
			aaoh.kaze.Element.setForeground(
				aaoh.sora.App.main.lblHour,    aaoh.sora.App.main.lblFgColor
			);
			aaoh.kaze.Element.setForeground(
				aaoh.sora.App.main.lblHourSep, aaoh.sora.App.main.lblFgColor
			);
			aaoh.kaze.Element.setForeground(
				aaoh.sora.App.main.lblMin,     aaoh.sora.App.main.lblFgColor
			);
			aaoh.kaze.Element.setForeground(
				aaoh.sora.App.main.lblMinSep,  aaoh.sora.App.main.lblFgColor
			);
			aaoh.kaze.Element.setForeground(
				aaoh.sora.App.main.lblSec,     aaoh.sora.App.main.lblFgColor
			);
			aaoh.kaze.Element.setForeground(
				aaoh.sora.App.main.lblSecSep,  aaoh.sora.App.main.lblFgColor
			);
			aaoh.kaze.Element.setForeground(
				aaoh.sora.App.main.lblMsec,    aaoh.sora.App.main.lblFgColor
			);
			aaoh.kaze.Element.setForeground(
				aaoh.sora.App.main.lblPreset,  aaoh.sora.App.main.lblFgColor
			);
		}, 500);

		// sbm対応
		if (aaoh.kaze.Type.isSBM()) {
			// バイブレーション
			widget.system.vibrate(5); // 500msec
		}

		if (this.alertTimer2.id == null) {
			this.alertTimer2.setInterval(function() {
				aaoh.sora.App.main.showTimerAlert();
			}, 1000);
		}
	}

	/**
	 * アラート表示。
	 */
	timer.Main.prototype.
	showAlertMsg = function() {
		if (!aaoh.sora.App.model.data.isAlert) {
			return;
		}

		var alertMsg = null;
		if (aaoh.sora.App.model.data.isAlertDef) {
			alertMsg = aaoh.sora.App.control.DEFAULT_ALERT_MSG;

		} else {
			alertMsg = aaoh.sora.App.model.data.alertMsg;
		}

		// ポップアップ表示
		aaoh.kaze.Gadget.confirm(alertMsg, function() {
			aaoh.sora.App.main.doStop();
		}, this);
	}

	/**
	 * 時間計測。
	 */
	timer.Main.prototype.
	timer = function() {
		if (this.flgSts != aaoh.sora.App.control.FLG_START) {
			return;
		}

		// 計測時刻の判定
		var time       = new Date().getTime();
		var remainTime = this.stopTime - time;
		if (remainTime <= 0) {
			// アラート処理
			this.showAlert();
			return;
		}

		switch (aaoh.sora.App.model.data.mode) {
			case aaoh.sora.App.control.MODE_COUNTDOWN:
			default:
				break;

			case aaoh.sora.App.control.MODE_COUNTUP:
				remainTime = this.measureTime - remainTime;
				break;
		}

		this.showTimer(remainTime);
		this.dispTimer.setTimeout(function() {
			aaoh.sora.App.main.timer();
		}, aaoh.sora.App.control.INTERVAL);
	}

	/**
	 * 音の再生。
	 */
	timer.Main.prototype.
	soundPlay = function() {
		if (!aaoh.sora.App.model.data.isSound) {
			return;
		}

		// 音を鳴らす
		var soundFile = null;
		if (aaoh.sora.App.model.data.isSoundDef) {
			soundFile = aaoh.sora.App.control.DEFAULT_SOUND_FILE;

		} else {
			soundFile = aaoh.sora.App.model.data.soundFile;
		}

		// volume
		if (aaoh.sora.App.control.sound.isVolume()) {
			var numSoundVol = aaoh.sora.App.model.data.numSoundVol;
			aaoh.sora.App.control.sound.setVolume(numSoundVol);
		}

		// repeat
		if (aaoh.sora.App.control.sound.isRepeat()) {
			aaoh.sora.App.control.sound.setRepeat(true);

		} else {
			// 固定時間でリピート再生する
			this.alarmRepeatFile = soundFile;
			this.alarmRepeatTimer.setInterval(function() {
				aaoh.sora.App.control.sound.play(
					aaoh.sora.App.main.alarmRepeatFile
				);
			}, aaoh.sora.App.control.DEFAULT_REPEAT_INTERVAL);
		}

		aaoh.sora.App.control.sound.play(soundFile);
	}

	/**
	 * 音の停止。
	 */
	timer.Main.prototype.
	soundStop = function() {
		if (!aaoh.sora.App.model.data.isSound) {
			return;
		}

		this.alarmRepeatTimer.clearInterval();
		aaoh.sora.App.control.sound.stop();
	}

	/**
	 * アラーム設定の開始(時)。
	 *
	 * @param {Boolean} isAdd 値を加算するときにはtrue
	 */
	timer.Main.prototype.
	addAlarmSetHour = function(isAdd) {
		if (this.flgSts != aaoh.sora.App.control.FLG_STOP) {
			return;
		}

		this.isAlarmSetHourAdd = isAdd;
		this.setAlarmSetHour(isAdd);

		this.alarmSetHourTimer.setInterval(function() {
			aaoh.sora.App.main.setAlarmSetHour(
				aaoh.sora.App.main.isAlarmSetHourAdd
			);
		}, this.ALARM_SET_INTERVAL);
	}

	/**
	 * アラーム設定の停止(時)。
	 */
	timer.Main.prototype.
	stopAlarmSetHour = function() {
		this.alarmSetHourTimer.clearInterval();
	}

	/**
	 * アラーム設定の開始(分)。
	 *
	 * @param {Boolean} isAdd 値を加算するときにはtrue
	 */
	timer.Main.prototype.
	addAlarmSetMin = function(isAdd) {
		if (this.flgSts != aaoh.sora.App.control.FLG_STOP) {
			return;
		}

		this.isAlarmSetMinAdd = isAdd;
		this.setAlarmSetMin(isAdd);

		this.alarmSetMinTimer.setInterval(function() {
			aaoh.sora.App.main.setAlarmSetMin(
				aaoh.sora.App.main.isAlarmSetMinAdd
			);
		}, this.ALARM_SET_INTERVAL);
	}

	/**
	 * アラーム設定の停止(分)。
	 */
	timer.Main.prototype.
	stopAlarmSetMin = function() {
		this.alarmSetMinTimer.clearInterval();
	}

	/**
	 * アラーム設定の開始(秒)。
	 *
	 * @param {Boolean} isAdd 値を加算するときにはtrue
	 */
	timer.Main.prototype.
	addAlarmSetSec = function(isAdd) {
		if (this.flgSts != aaoh.sora.App.control.FLG_STOP) {
			return;
		}

		this.isAlarmSetSecAdd = isAdd;
		this.setAlarmSetSec(isAdd);

		this.alarmSetSecTimer.setInterval(function() {
			aaoh.sora.App.main.setAlarmSetSec(
				aaoh.sora.App.main.isAlarmSetSecAdd
			);
		}, this.ALARM_SET_INTERVAL);
	}

	/**
	 * アラーム設定の停止(秒)。
	 */
	timer.Main.prototype.
	stopAlarmSetSec = function() {
		this.alarmSetSecTimer.clearInterval();
	}

	/**
	 * アラーム設定(時)。
	 *
	 * @param {Boolean} isAdd 値を加算するときにはtrue
	 */
	timer.Main.prototype.
	setAlarmSetHour = function(isAdd) {
		var alarmHour    = aaoh.kaze.Element.getValue(this.lblHour);
		var numAlarmHour = parseInt(alarmHour, 10);

		// 値の加算
		if (isAdd) {
			numAlarmHour++;

		} else {
			numAlarmHour--;
		}

		if (numAlarmHour < 0) {
			numAlarmHour = 9;

		} else if (numAlarmHour > 9) {
			numAlarmHour = 0;
		}

		var alarmHourValue = numAlarmHour.toString();
		//if (alarmHourValue.length <= 1) {
		//	alarmHourValue = '0' + alarmHourValue;
		//}
		aaoh.kaze.Element.setValue(this.lblHour, alarmHourValue);
	}

	/**
	 * アラーム設定(分)。
	 *
	 * @param {Boolean} isAdd 値を加算するときにはtrue
	 */
	timer.Main.prototype.
	setAlarmSetMin = function(isAdd) {
		var alarmMin    = aaoh.kaze.Element.getValue(this.lblMin);
		var numAlarmMin = parseInt(alarmMin, 10);

		// 値の加算
		if (isAdd) {
			numAlarmMin++;

		} else {
			numAlarmMin--;
		}

		if (numAlarmMin < 0) {
			numAlarmMin = 59;
			this.setAlarmSetHour(false);

		} else if (numAlarmMin > 59) {
			numAlarmMin = 0;
			this.setAlarmSetHour(true);
		}

		var alarmMinValue = numAlarmMin.toString();
		if (alarmMinValue.length <= 1) {
			alarmMinValue = '0' + alarmMinValue;
		}
		aaoh.kaze.Element.setValue(this.lblMin, alarmMinValue);
	}

	/**
	 * アラーム設定(秒)。
	 *
	 * @param {Boolean} isAdd 値を加算するときにはtrue
	 */
	timer.Main.prototype.
	setAlarmSetSec = function(isAdd) {
		var alarmSec    = aaoh.kaze.Element.getValue(this.lblSec);
		var numAlarmSec = parseInt(alarmSec, 10);

		// 値の加算
		if (isAdd) {
			numAlarmSec++;

		} else {
			numAlarmSec--;
		}

		if (numAlarmSec < 0) {
			numAlarmSec = 59;
			this.setAlarmSetMin(false);

		} else if (numAlarmSec > 59) {
			numAlarmSec = 0;
			this.setAlarmSetMin(true);
		}

		var alarmSecValue = numAlarmSec.toString();
		if (alarmSecValue.length <= 1) {
			alarmSecValue = '0' + alarmSecValue;
		}
		aaoh.kaze.Element.setValue(this.lblSec, alarmSecValue);
	}

	/**
	 * 表示データの初期化。
	 */
	timer.Main.prototype.
	initData = function() {
		// デフォルト値の更新
		aaoh.sora.App.control.DEFAULT_ALERT_MSG
			= aaoh.sora.App.control.locale.getString('ALERT_MSG');

		//var flgOnDock = aaoh.sora.App.control.flgOnDock;
		var type      = aaoh.sora.App.model.data.type;

		this.initToolbarData(type);

		var main    = aaoh.kaze.Gadget.$('main');
		var srcMain = null;
		if (aaoh.kaze.Type.isSidebar()) {
			srcMain = 'lib/aaoh.sora.t.png';

		} else {
			srcMain = 'images/timer' + type + '-base.png';
		}
		// IE6では入れ子透過PNG対応しない
		aaoh.kaze.Element.setBackgroundImage(main, srcMain, false);

		// 透過PNG対応
		if (aaoh.kaze.Type.isSidebar()) {
			var sidebarImgBg    = aaoh.kaze.Gadget.$('sidebarImgBg');
			var srcSidebarImgBg = 'images/timer' + type + '-base_sidebar.png';
			aaoh.kaze.Element.setImage(sidebarImgBg, srcSidebarImgBg);
		}

		this.initTimerData(type);

		// 初期設定の設定
		this.setStartTime(1);

		this.dispTimer.setTimeout(function() {
			aaoh.sora.App.main.setFocus();
		}, 200);
	}

	/**
	 * 表示データの初期化。
	 *
	 * @param {String} type 表示タイプ
	 */
	timer.Main.prototype.
	initToolbarData = function(type) {
		var btnOption = aaoh.kaze.Gadget.$('btnOption');
		var btnClose  = aaoh.kaze.Gadget.$('btnClose');
		if (btnOption == null || btnClose == null) {
			return;
		}

		var srcBtnOptionUp   = null;
		var srcBtnOptionOver = null;
		var srcBtnOptionDown = null;
		var srcBtnCloseUp    = null;
		var srcBtnCloseOver  = null;
		var srcBtnCloseDown  = null;
		if (!aaoh.kaze.Type.isGoogle() && !aaoh.kaze.Type.isIE()) {
			srcBtnOptionUp = 'images/timer' + type + '-option.png';
			srcBtnCloseUp  = 'images/timer' + type + '-close.png';

		} else {
			srcBtnOptionUp = 'sub-images/timer' + type + '-option_up.png';
			srcBtnCloseUp  = 'sub-images/timer' + type + '-close_up.png';
		}
		srcBtnOptionOver = 'sub-images/timer' + type + '-option_over.png';
		srcBtnOptionDown = 'sub-images/timer' + type + '-option_down.png';
		srcBtnCloseOver  = 'sub-images/timer' + type + '-close_over.png';
		srcBtnCloseDown  = 'sub-images/timer' + type + '-close_down.png';

		aaoh.kaze.Element.setBackgroundImage(
			btnOption, srcBtnOptionUp, srcBtnOptionOver, srcBtnOptionDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnClose, srcBtnCloseUp, srcBtnCloseOver, srcBtnCloseDown
		);
	}

	/**
	 * 表示データの初期化。
	 *
	 * @param {String} type 表示タイプ
	 */
	timer.Main.prototype.
	initTimerData = function(type) {
		var btnSetHourUp   = aaoh.kaze.Gadget.$('btnSetHourUp');
		var btnSetHourDown = aaoh.kaze.Gadget.$('btnSetHourDown');
		var btnSetMinUp    = aaoh.kaze.Gadget.$('btnSetMinUp');
		var btnSetMinDown  = aaoh.kaze.Gadget.$('btnSetMinDown');
		var btnSetSecUp    = aaoh.kaze.Gadget.$('btnSetSecUp');
		var btnSetSecDown  = aaoh.kaze.Gadget.$('btnSetSecDown');
		var btnPreset1     = aaoh.kaze.Gadget.$('btnPreset1');
		var btnPreset2     = aaoh.kaze.Gadget.$('btnPreset2');
		var btnPreset3     = aaoh.kaze.Gadget.$('btnPreset3');

		var fgColor = null;
		//var bgColor = null;
		switch (type) {
			default:
			case '1':
				fgColor = '#7f7f7f';
				//bgColor = '#ffffff';
				break;

			case '2':
				fgColor = '#ffffff';
				//bgColor = '#000000';
				break;

			case '3':
				fgColor = '#ffffff';
				//bgColor = '#ff0000';
				break;

			case '4':
				fgColor = '#7f7f7f';
				//bgColor = '#000000';
				break;

			case '5':
				fgColor = '#ffffff';
				//bgColor = '#ff0000';
				break;

			case '6':
				fgColor = '#ffffff';
				//bgColor = '#000000';
				break;
		}
		aaoh.kaze.Element.setForeground(this.lblHour,    fgColor);
		aaoh.kaze.Element.setForeground(this.lblHourSep, fgColor);
		aaoh.kaze.Element.setForeground(this.lblMin,     fgColor);
		aaoh.kaze.Element.setForeground(this.lblMinSep,  fgColor);
		aaoh.kaze.Element.setForeground(this.lblSec,     fgColor);
		aaoh.kaze.Element.setForeground(this.lblSecSep,  fgColor);
		aaoh.kaze.Element.setForeground(this.lblMsec,    fgColor);
		aaoh.kaze.Element.setForeground(this.lblPreset,  fgColor);

		var srcBtnAllowUpUp     = null;
		var srcBtnAllowUpOver   = null;
		var srcBtnAllowUpDown   = null;
		var srcBtnAllowDownUp   = null;
		var srcBtnAllowDownOver = null;
		var srcBtnAllowDownDown = null;
		var srcBtnStartUp       = null;
		var srcBtnStartOver     = null;
		var srcBtnStartDown     = null;
		var srcBtnSuspendUp     = null;
		var srcBtnSuspendOver   = null;
		var srcBtnSuspendDown   = null;
		var srcBtnStopUp        = null;
		var srcBtnStopOver      = null;
		var srcBtnStopDown      = null;
		var srcBtnPreset1Up     = null;
		var srcBtnPreset1Over   = null;
		var srcBtnPreset1Down   = null;
		var srcBtnPreset2Up     = null;
		var srcBtnPreset2Over   = null;
		var srcBtnPreset2Down   = null;
		var srcBtnPreset3Up     = null;
		var srcBtnPreset3Over   = null;
		var srcBtnPreset3Down   = null;
		if (!aaoh.kaze.Type.isGoogle() && !aaoh.kaze.Type.isIE()) {
			srcBtnAllowUpUp   = 'images/timer' + type + '-allow-up.png';
			srcBtnAllowDownUp = 'images/timer' + type + '-allow-down.png';
			srcBtnStartUp     = 'images/timer' + type + '-start.png';
			srcBtnSuspendUp   = 'images/timer' + type + '-suspend.png';
			srcBtnStopUp      = 'images/timer' + type + '-stop.png';
			srcBtnPreset1Up   = 'images/timer' + type + '-1.png';
			srcBtnPreset2Up   = 'images/timer' + type + '-2.png';
			srcBtnPreset3Up   = 'images/timer' + type + '-3.png';

		} else {
			srcBtnAllowUpUp   = 'sub-images/timer' + type + '-allow-up_up.png';
			srcBtnAllowDownUp = 'sub-images/timer' + type + '-allow-down_up.png';
			srcBtnStartUp     = 'sub-images/timer' + type + '-start_up.png';
			srcBtnSuspendUp   = 'sub-images/timer' + type + '-suspend_up.png';
			srcBtnStopUp      = 'sub-images/timer' + type + '-stop_up.png';
			srcBtnPreset1Up   = 'sub-images/timer' + type + '-1_up.png';
			srcBtnPreset2Up   = 'sub-images/timer' + type + '-2_up.png';
			srcBtnPreset3Up   = 'sub-images/timer' + type + '-3_up.png';
		}
		srcBtnAllowUpOver   = 'sub-images/timer' + type + '-allow-up_over.png';
		srcBtnAllowUpDown   = 'sub-images/timer' + type + '-allow-up_down.png';
		srcBtnAllowDownOver = 'sub-images/timer' + type + '-allow-down_over.png';
		srcBtnAllowDownDown = 'sub-images/timer' + type + '-allow-down_down.png';
		srcBtnStartOver     = 'sub-images/timer' + type + '-start_over.png';
		srcBtnStartDown     = 'sub-images/timer' + type + '-start_down.png';
		srcBtnSuspendOver   = 'sub-images/timer' + type + '-suspend_over.png';
		srcBtnSuspendDown   = 'sub-images/timer' + type + '-suspend_down.png';
		srcBtnStopOver      = 'sub-images/timer' + type + '-stop_over.png';
		srcBtnStopDown      = 'sub-images/timer' + type + '-stop_down.png';
		srcBtnPreset1Over   = 'sub-images/timer' + type + '-1_over.png';
		srcBtnPreset1Down   = 'sub-images/timer' + type + '-1_down.png';
		srcBtnPreset2Over   = 'sub-images/timer' + type + '-2_over.png';
		srcBtnPreset2Down   = 'sub-images/timer' + type + '-2_down.png';
		srcBtnPreset3Over   = 'sub-images/timer' + type + '-3_over.png';
		srcBtnPreset3Down   = 'sub-images/timer' + type + '-3_down.png';

		aaoh.kaze.Element.setBackgroundImage(
			btnSetHourUp, srcBtnAllowUpUp, srcBtnAllowUpOver, srcBtnAllowUpDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnSetHourDown, srcBtnAllowDownUp, srcBtnAllowDownOver, srcBtnAllowDownDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnSetMinUp, srcBtnAllowUpUp, srcBtnAllowUpOver, srcBtnAllowUpDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnSetMinDown, srcBtnAllowDownUp, srcBtnAllowDownOver, srcBtnAllowDownDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnSetSecUp, srcBtnAllowUpUp, srcBtnAllowUpOver, srcBtnAllowUpDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnSetSecDown, srcBtnAllowDownUp, srcBtnAllowDownOver, srcBtnAllowDownDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			this.btnStart, srcBtnStartUp, srcBtnStartOver, srcBtnStartDown
		);
		//aaoh.kaze.Element.setBackgroundImage(
		//	this.btnStart, srcBtnSuspendUp, srcBtnSuspendOver, srcBtnSuspendDown
		//);
		aaoh.kaze.Element.setBackgroundImage(
			this.btnStop, srcBtnStopUp, srcBtnStopOver, srcBtnStopDown
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnPreset1, srcBtnPreset1Up, srcBtnPreset1Over, srcBtnPreset1Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnPreset2, srcBtnPreset2Up, srcBtnPreset2Over, srcBtnPreset2Down
		);
		aaoh.kaze.Element.setBackgroundImage(
			btnPreset3, srcBtnPreset3Up, srcBtnPreset3Over, srcBtnPreset3Down
		);

		var tipSetHourUp   = aaoh.sora.App.control.locale.getString('TIP_SET_HOUR_UP');
		var tipSetHourDown = aaoh.sora.App.control.locale.getString('TIP_SET_HOUR_DOWN');
		var tipSetMinUp    = aaoh.sora.App.control.locale.getString('TIP_SET_MIN_UP');
		var tipSetMinDown  = aaoh.sora.App.control.locale.getString('TIP_SET_MIN_DOWN');
		var tipSetSecUp    = aaoh.sora.App.control.locale.getString('TIP_SET_SEC_UP');
		var tipSetSecDown  = aaoh.sora.App.control.locale.getString('TIP_SET_SEC_DOWN');
		var tipStart       = aaoh.sora.App.control.locale.getString('TIP_TIME_START');
		var tipStop        = aaoh.sora.App.control.locale.getString('TIP_TIME_STOP');
		var ttlPreset      = aaoh.sora.App.control.locale.getString('TTL_PRESET');

		aaoh.kaze.Element.setTooltip(btnSetHourUp,   tipSetHourUp);
		aaoh.kaze.Element.setTooltip(btnSetHourDown, tipSetHourDown);
		aaoh.kaze.Element.setTooltip(btnSetMinUp,    tipSetMinUp);
		aaoh.kaze.Element.setTooltip(btnSetMinDown,  tipSetMinDown);
		aaoh.kaze.Element.setTooltip(btnSetSecUp,    tipSetSecUp);
		aaoh.kaze.Element.setTooltip(btnSetSecDown,  tipSetSecDown);
		aaoh.kaze.Element.setTooltip(this.btnStart,  tipStart);
		aaoh.kaze.Element.setTooltip(this.btnStop,   tipStop);
		aaoh.kaze.Element.setValue(this.lblPreset,   ttlPreset);

		// イメージの保存
		this.lblFgColor = fgColor;
		this.btnBgImgs[aaoh.sora.App.control.FLG_START] = new Array(
			srcBtnStartUp, srcBtnStartOver, srcBtnStartDown
		);
		this.btnBgImgs[aaoh.sora.App.control.FLG_SUSPEND] = new Array(
			srcBtnSuspendUp, srcBtnSuspendOver, srcBtnSuspendDown
		);
		this.btnBgImgs[aaoh.sora.App.control.FLG_STOP] = new Array(
			srcBtnStopUp, srcBtnStopOver, srcBtnStopDown
		);
	}

	/**
	 * イベントの設定。
	 */
	timer.Main.prototype.
	setEventListener = function() {
		if (this.topObj != null) {
			aaoh.kaze.Element.setOnKeyDown(this.topObj, function(event) {
				aaoh.sora.App.main.setImgInput(event);
			});
			aaoh.kaze.Element.setOnKeyUp(this.topObj, function(event) {
				aaoh.sora.App.main.doInput(event);
			});
		}

		var btnStart = aaoh.kaze.Gadget.$('btnStart');
		if (btnStart != null) {
			aaoh.kaze.Element.setOnMouseDown(btnStart, function() {
				aaoh.sora.App.main.setStartPushImg();
			});
			aaoh.kaze.Element.setOnMouseUp(btnStart, function() {
				aaoh.sora.App.main.doStart();
				aaoh.sora.App.main.setFocus();
			});
		}

		var btnStop = aaoh.kaze.Gadget.$('btnStop');
		if (btnStop != null) {
			aaoh.kaze.Element.setOnMouseDown(btnStop, function() {
				aaoh.sora.App.main.setStopPushImg();
			});
			aaoh.kaze.Element.setOnMouseUp(btnStop, function() {
				aaoh.sora.App.main.doStop();
				aaoh.sora.App.main.setFocus();
			});
		}

		this.setTimerEventListener();
		this.setPresetEventListener();
	}

	/**
	 * イベントの設定。
	 */
	timer.Main.prototype.
	setTimerEventListener = function() {
		var btnSetHourUp = aaoh.kaze.Gadget.$('btnSetHourUp');
		if (btnSetHourUp != null) {
			aaoh.kaze.Element.setOnMouseDown(btnSetHourUp, function() {
				aaoh.sora.App.main.addAlarmSetHour(true);
			});
			aaoh.kaze.Element.setOnMouseUp(btnSetHourUp, function() {
				aaoh.sora.App.main.stopAlarmSetHour();
				aaoh.sora.App.main.setFocus();
			});

			if (!aaoh.kaze.Type.isYahoo()) {
				aaoh.kaze.Element.setOnMouseOut(btnSetHourUp, function() {
					aaoh.sora.App.main.stopAlarmSetHour();
					aaoh.sora.App.main.setFocus();
				});
			}
		}
		var btnSetHourDown = aaoh.kaze.Gadget.$('btnSetHourDown');
		if (btnSetHourDown != null) {
			aaoh.kaze.Element.setOnMouseDown(btnSetHourDown, function() {
				aaoh.sora.App.main.addAlarmSetHour(false);
			});
			aaoh.kaze.Element.setOnMouseUp(btnSetHourDown, function() {
				aaoh.sora.App.main.stopAlarmSetHour();
				aaoh.sora.App.main.setFocus();
			});

			if (!aaoh.kaze.Type.isYahoo()) {
				aaoh.kaze.Element.setOnMouseOut(btnSetHourDown, function() {
					aaoh.sora.App.main.stopAlarmSetHour();
					aaoh.sora.App.main.setFocus();
				});
			}
		}

		var btnSetMinUp = aaoh.kaze.Gadget.$('btnSetMinUp');
		if (btnSetMinUp != null) {
			aaoh.kaze.Element.setOnMouseDown(btnSetMinUp, function() {
				aaoh.sora.App.main.addAlarmSetMin(true);
			});
			aaoh.kaze.Element.setOnMouseUp(btnSetMinUp, function() {
				aaoh.sora.App.main.stopAlarmSetMin();
				aaoh.sora.App.main.setFocus();
			});

			if (!aaoh.kaze.Type.isYahoo()) {
				aaoh.kaze.Element.setOnMouseOut(btnSetMinUp, function() {
					aaoh.sora.App.main.stopAlarmSetMin();
					aaoh.sora.App.main.setFocus();
				});
			}
		}
		var btnSetMinDown = aaoh.kaze.Gadget.$('btnSetMinDown');
		if (btnSetMinDown != null) {
			aaoh.kaze.Element.setOnMouseDown(btnSetMinDown, function() {
				aaoh.sora.App.main.addAlarmSetMin(false);
			});
			aaoh.kaze.Element.setOnMouseUp(btnSetMinDown, function() {
				aaoh.sora.App.main.stopAlarmSetMin();
				aaoh.sora.App.main.setFocus();
			});

			if (!aaoh.kaze.Type.isYahoo()) {
				aaoh.kaze.Element.setOnMouseOut(btnSetMinDown, function() {
					aaoh.sora.App.main.stopAlarmSetMin();
					aaoh.sora.App.main.setFocus();
				});
			}
		}

		var btnSetSecUp = aaoh.kaze.Gadget.$('btnSetSecUp');
		if (btnSetSecUp != null) {
			aaoh.kaze.Element.setOnMouseDown(btnSetSecUp, function() {
				aaoh.sora.App.main.addAlarmSetSec(true);
			});
			aaoh.kaze.Element.setOnMouseUp(btnSetSecUp, function() {
				aaoh.sora.App.main.stopAlarmSetSec();
				aaoh.sora.App.main.setFocus();
			});

			if (!aaoh.kaze.Type.isYahoo()) {
				aaoh.kaze.Element.setOnMouseOut(btnSetSecUp, function() {
					aaoh.sora.App.main.stopAlarmSetSec();
					aaoh.sora.App.main.setFocus();
				});
			}
		}
		var btnSetSecDown = aaoh.kaze.Gadget.$('btnSetSecDown');
		if (btnSetSecDown != null) {
			aaoh.kaze.Element.setOnMouseDown(btnSetSecDown, function() {
				aaoh.sora.App.main.addAlarmSetSec(false);
			});
			aaoh.kaze.Element.setOnMouseUp(btnSetSecDown, function() {
				aaoh.sora.App.main.stopAlarmSetSec();
				aaoh.sora.App.main.setFocus();
			});

			if (!aaoh.kaze.Type.isYahoo()) {
				aaoh.kaze.Element.setOnMouseOut(btnSetSecDown, function() {
					aaoh.sora.App.main.stopAlarmSetSec();
					aaoh.sora.App.main.setFocus();
				});
			}
		}
	}

	/**
	 * イベントの設定。
	 */
	timer.Main.prototype.
	setPresetEventListener = function() {
		var btnPreset1 = aaoh.kaze.Gadget.$('btnPreset1');
		if (btnPreset1 != null) {
			aaoh.kaze.Element.setOnClick(btnPreset1, function() {
				aaoh.sora.App.main.setStartTime(1);
				aaoh.sora.App.main.setFocus();
			});
		}

		var btnPreset2 = aaoh.kaze.Gadget.$('btnPreset2');
		if (btnPreset2 != null) {
			aaoh.kaze.Element.setOnClick(btnPreset2, function() {
				aaoh.sora.App.main.setStartTime(2);
				aaoh.sora.App.main.setFocus();
			});
		}

		var btnPreset3 = aaoh.kaze.Gadget.$('btnPreset3');
		if (btnPreset3 != null) {
			aaoh.kaze.Element.setOnClick(btnPreset3, function() {
				aaoh.sora.App.main.setStartTime(3);
				aaoh.sora.App.main.setFocus();
			});
		}
	}

	/**
	 * 初期化処理。
	 */
	timer.Main.prototype.
	init = function() {
		// 設定情報のデフォルト設定
		if (!aaoh.kaze.Gadget.isConfirm()) {
			aaoh.sora.App.model.data.isAlert = false;
		}
		if (!aaoh.sora.App.control.sound.isSound()) {
			aaoh.sora.App.model.data.isSound = false;
		}

		this.setEventListener();
	}
})();
